#
# spec file for package libluksde
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libluksde1
Name:           libluksde
Version:        20240503
Release:        1.3
Summary:        Library and tools to access LUKS Disk Encryption encrypted files
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libluksde
Source:         https://github.com/libyal/libluksde/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libluksde/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source9:        %name.keyring
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcaes) >= 20240413
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfcache) >= 20240414
BuildRequires:  pkgconfig(libfcrypto) >= 20240414
BuildRequires:  pkgconfig(libfdatetime) >= 20240414
BuildRequires:  pkgconfig(libfguid) >= 20240414
BuildRequires:  pkgconfig(libhmac) >= 20240417
BuildRequires:  pkgconfig(libuna) >= 20240414
BuildRequires:  pkgconfig(python3)
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library and tools to access the New Technology File System (NTFS).

Note that this project currently only focuses on the analysis of the format.

%package -n %lname
Summary:        Library to access the New Technology File System (NTFS)
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libluksde is a library to access LUKS Disk Encrypted volumes.

%package tools
Summary:        Tools to access the New Technology File System (NTFS)
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
libluksde-tools is a project to access LUKS Disk Encrypted volumes.

%package devel
Summary:        Development files for libluksde
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
%name is a library to access the New Technology File System (NTFS).

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find "%buildroot" -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libluksde.so.*

%files -n %name-tools
%_bindir/luksde*
%_mandir/man1/luksdeinfo.1*
%_mandir/man1/luksdemount.1*

%files -n %name-devel
%_includedir/libluksde.h
%_includedir/libluksde/
%_libdir/libluksde.so
%_libdir/pkgconfig/libluksde.pc
%_mandir/man3/libluksde.3*

%files %python_files
%license COPYING*
%python_sitearch/pyluksde.so

%changelog
* Fri May  3 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240503
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Sun Jan 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240114
  * Support for Blowfish-{CBC,EBC}
* Tue Dec  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231205
  * No user-relevant changes
* Wed Nov 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231128
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Thu Nov  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221103
  * No changelog was provided
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220807
  * No changelog was provided
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220121
  * Unspecified changes to volume unlocking.
* Wed Jun 30 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove unnecessary BuildRequires on python-devel
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210419 (7b40e4b7)
  * No changelog was provided
- Add system-libs.patch
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Sun Apr  5 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- initial package version v0~20200205 in opensuse build service
